@@ -21,18 +21,18 @@ AsyncImageResponse::AsyncImageResponse(const QString &id, const QSize &requested
 #ifdef KIO_AVAILABLE
     KIO::PreviewJob::setDefaultDevicePixelRatio(qApp->devicePixelRatio());
     QStringList plugins = KIO::PreviewJob::availablePlugins();
-//     qDebug() << plugins << KIO::PreviewJob::defaultPlugins();
+    //     qDebug() << plugins << KIO::PreviewJob::defaultPlugins();
     auto job = new KIO::PreviewJob(KFileItemList() << KFileItem(QUrl::fromUserInput(id)), requestedSize, &plugins);
 
     connect(job, &KIO::PreviewJob::gotPreview, [this](KFileItem, QPixmap pixmap) {
         m_image = pixmap.toImage();
-        emit this->finished();
+        Q_EMIT this->finished();
     });
 
     connect(job, &KIO::PreviewJob::failed, [this](KFileItem) {
-        m_error = "Thumbnail Previewer job failed";
+        m_error = QStringLiteral("Thumbnail Previewer job failed");
         this->cancel();
-        emit this->finished();
+        Q_EMIT this->finished();
     });
 
     job->start();
